==> pi_anwing_webthing-0.0.1.tar.gz: pi_anwing_webthing-0.0.1/pi_anwing_webthing/switch.py <==
import RPi.GPIO as GPIO
from typing import List
from pi_anwing_webthing.anwing import Anwing


class Switch:
    STOP = (False, False)
    MOVE_FORWARD = (True, False)
    MOVE_BACKWARD = (False, True)
    IDLE = (True, True)

    def __init__(self, pin_forward: int, pin_backward: int, anwings: List[Anwing]):
        self.anwings = anwings
        self.pin_forward = pin_forward
        self.pin_backward = pin_backward
        self.state = self.STOP
        GPIO.setmode(GPIO.BCM)
        GPIO.setup(self.pin_forward, GPIO.IN, GPIO.PUD_DOWN)
        GPIO.add_event_detect(self.pin_forward, GPIO.BOTH)
        GPIO.add_event_callback(self.pin_forward, self.on_switch_updated)
        GPIO.setup(self.pin_backward, GPIO.IN, GPIO.PUD_DOWN)
        GPIO.add_event_detect(self.pin_backward, GPIO.BOTH)
        GPIO.add_event_callback(self.pin_backward, self.on_switch_updated)
        print("bound to PIN_FORWARD=" + str(self.pin_forward) + " and PIN_BACKWARD=" + str(self.pin_backward))

    def is_forward(self) -> bool:
        return self.state[0]

    def is_backward(self) -> bool:
        return self.state[1]

    def on_switch_updated(self, pin: int):
        print("event occurred on pin " + str(pin))
        is_forward = GPIO.input(self.pin_forward) >= 1
        is_backward = GPIO.input(self.pin_backward) >= 1
        new_state = (is_forward, is_backward)
        print("current state " + str(self.state))
        print("new state     " + str(new_state))
        try:
            if self.state != new_state:
                if new_state == self.MOVE_FORWARD:
                    for anwing in self.anwings:
                        anwing.set_target_position(100)
                elif new_state == self.MOVE_BACKWARD:
                    for anwing in self.anwings:
                        anwing.set_target_position(0)
                elif new_state == self.STOP:
                    for anwing in self.anwings:
                        current_pos = anwing.get_current_position()
                        anwing.set_target_position(current_pos)
                else:
                    pass
        finally:
            self.state = new_state

==> pi_anwing_webthing-0.1.1.tar.gz: pi_anwing_webthing-0.1.1/pi_anwing_webthing/switch.py <==
import logging
import RPi.GPIO as GPIO
from typing import List
from pi_anwing_webthing.anwing import Anwing


class Switch:
    STOP = (False, False)
    MOVE_FORWARD = (True, False)
    MOVE_BACKWARD = (False, True)
    IDLE = (True, True)

    def __init__(self, pin_forward: int, pin_backward: int, anwings: List[Anwing]):
        self.anwings = anwings
        self.pin_forward = pin_forward
        self.pin_backward = pin_backward
        self.state = self.STOP
        GPIO.setmode(GPIO.BCM)
        GPIO.setup(self.pin_forward, GPIO.IN, GPIO.PUD_DOWN)
        GPIO.add_event_detect(self.pin_forward, GPIO.BOTH)
        GPIO.add_event_callback(self.pin_forward, self.on_switch_updated)
        GPIO.setup(self.pin_backward, GPIO.IN, GPIO.PUD_DOWN)
        GPIO.add_event_detect(self.pin_backward, GPIO.BOTH)
        GPIO.add_event_callback(self.pin_backward, self.on_switch_updated)
        logging.info("bound to PIN_FORWARD=" + str(self.pin_forward) + " and PIN_BACKWARD=" + str(self.pin_backward))

    def is_forward(self) -> bool:
        return self.state[0]

    def is_backward(self) -> bool:
        return self.state[1]

    def on_switch_updated(self, pin: int):
        is_forward = GPIO.input(self.pin_forward) >= 1
        is_backward = GPIO.input(self.pin_backward) >= 1
        new_state = (is_forward, is_backward)
        logging.info("switch new state     " + str(new_state) + " (old " + str(self.state) + ")")
        try:
            if self.state != new_state:
                if new_state == self.MOVE_FORWARD:
                    for anwing in self.anwings:
                        anwing.set_target_position(100)
                elif new_state == self.MOVE_BACKWARD:
                    for anwing in self.anwings:
                        anwing.set_target_position(0)
                elif new_state == self.STOP:
                    for anwing in self.anwings:
                        current_pos = anwing.get_current_position()
                        anwing.set_target_position(current_pos)
                else:
                    pass
        finally:
            self.state = new_state
